# -*- coding: utf-8 -*-

"""
Epic Games Store API Wrapper
~~~~~~~~~~~~~~~~~~~

An API wrapper for Epic Games Store

:copyright: (c) 2020 SD4RK
:license: MIT, see LICENSE for more details.
"""


from .api import *
from .models import *
from .exc import EGSException, EGSNotFound
